import React, {useEffect, useState} from "react";
import {useStore} from "../../utils/useStore";
import {Button, Card, Col, Input, Modal, Row, Select} from "antd";
import {observer} from "mobx-react-lite";

const {Search} = Input;
const {Option} = Select;

export const Product = observer(() => {
    const store = useStore();

    const [isLoading, setIsLoading] = useState(false);
    const [productData, setProductData] = useState([]);

    useEffect(() => {
        const init = async () => {
            try {
                setIsLoading(true);
                await store.transaction.getDataSubCategories();
                await store.transaction.getDataCategories();
                setIsLoading(false);
            } catch (e) {
                setIsLoading(false);
            }
        };

        init();
    }, []);

    // data
    useEffect(() => {
        console.log('⚡ transaction data store', store.transaction.data)
        setProductData(store.transaction.data)
    }, [store.transaction.data])

    // Subcategory
    useEffect(() => {
        console.log('⚡ transaction subcategory store', store.transaction.dataSubCategories)
    }, [store.transaction.dataSubCategories])


    const handleChangeSubcategory = async (item) => {
        console.log('item', item);
        store.transaction.filterSubCategory = item;
        await store.transaction.getData();
    }

    const success = () => {
        Modal.success({
            content: 'some messages...some messages...',
        });
    }

    return (
        <div>
            <Row>
                <span style={{fontWeight: "bold", marginBottom: "10px"}}>
                    Sub-Category
                </span>
            </Row>
            <Row>
                <Col span={24}>
                    <Select
                        placeholder={"Select sub-Category"}
                        allowClear={true}
                        onChange={(val) => {
                            handleChangeSubcategory(val);
                        }}
                        style={{marginBottom: "10px", width: "100%"}}>
                        {store.transaction.dataSubCategories.map((item, index) => (
                            <Option key={item.id} value={item.id}>
                                {item.name}
                            </Option>
                        ))}
                    </Select>
                </Col>
            </Row>
            <Row justify={"center"} align={"center"} style={{marginBottom: "1rem"}}>
                <Col span={12} style={{fontWeight: "bold", display: "flex", alignItems: "center"}}>
                    Produk & Nominal
                </Col>
                <Col span={12} style={{textAlign: "right"}}>
                    <Search
                        placeholder="input search text"
                        style={{width: 200, marginRight: 10}}
                    />
                </Col>
            </Row>
            {productData.length != 0 && <Row>
                {productData.map((item, index) => (
                    <Col key={index} xs={24} md={16} lg={8}>
                        <Card onClick={success}>
                            <span style={{color: "black"}}>{item.name}</span>
                            <br/>
                            <span style={{color: "grey", fontSize: 10}}>{item.price}</span>
                        </Card>
                    </Col>
                ))}
            </Row>}
            {productData.length != 0 && <Col style={{textAlign: "right"}}>
                <Button style={{backgroundColor: "#2D9CDB", color: "white"}}>
                    Beli Sekarang
                </Button>
            </Col>}
        </div>
    );
});
